TaskToggleHandler

Type Alias TaskToggleHandler 

pub type TaskToggleHandler = Rc<dyn Fn(usize, &mut Window, &mut App)>;
Toggle the task checkbox of a clicked list item — the argument is the source byte offset of that task item (feed it to toggle_task_at). Set via MarkdownView::on_task_toggle.

Aliased Type

pub struct TaskToggleHandler { /* private fields */ }